<?php
require_once APPLICATION_PATH . '/models/Loading.php';
require_once APPLICATION_PATH . '/models/Waste.php';
require_once APPLICATION_PATH . '/models/Users.php';


class Form_Loading extends Zend_Form
{
	
	protected $_wasteSelect;
	protected $_udmSelect;
	protected $_progressivo;
	public $_data;
	
	private $buttonDateDecorators = array(
		'ViewHelper',
		array(array('data' => 'HtmlTag'), array('tag' => 'span', 'class' => 'buttondate'))
	);
	
	private $buttonPrintDateDecorators = array(
		'ViewHelper',
		array(array('data' => 'HtmlTag'), array('tag' => 'span', 'class' => 'buttonsubmit'))
	);
	
	private $dateDecorators = array(
		array('Errors'),
		array(array('ErrorsDiv' => 'HtmlTag'), array('tag' => 'div', 'class' => 'notice_error')),
		array('ViewHelper'),
		array('Description', array('tag' => 'div', 'class' => 'description')),
		array('Label', array('tag' => 'span')),
		array('HtmlTag', array('tag' => 'span')),
	);
	
	private $textDecorators = array(
		array('Errors'),
		array(array('ErrorsDiv' => 'HtmlTag'), array('tag' => 'div', 'class' => 'notice_error')),
		array('ViewHelper'),
		array('Description', array('tag' => 'div', 'class' => 'description')),
		array('Label', array('tag' => 'span')),
		array('HtmlTag', array('tag' => 'div', 'class' => 'field')),
	);
	
	private $proDecorators = array(
		array('Errors'),
		array(array('ErrorsDiv' => 'HtmlTag'), array('tag' => 'div', 'class' => 'notice_error')),
		array('ViewHelper'),
		array('Description', array('tag' => 'div', 'class' => 'description')),
		array('Label', array('tag' => 'span', 'class' => 'progressivo')),
		array('HtmlTag', array('tag' => 'div', 'class' => 'progressivo')),
	);
    
	public function init()
    {
        
        $this->setMethod('post');
		$this->setAttrib("id","loadingForm");
		
		$this->_progressivo = new Zend_Form_Element_Text('progressivo', array(
            'label'      => 'N.',
			'size'   => 5,
            'required'   => true,
            'filters'    => array('StringTrim'),
            'validators' => array(
                 array('validator' => 'Digits'),
				 array('validator' => 'StringLength', 'options' => array(0, 5))
            )
			));
		
		$this->addElement($this->_progressivo);
		
		$this->_data = new Zend_Form_Element_Text('data', array(
            'label'      => 'Data: ',
			'id'      => 'data',
			'size'   => 10,
			'readonly'      => true,
            'required'   => true,
            'filters'    => array('StringTrim'),
            'validators' => array(
                 array('validator' => 'StringLength', 'options' => array(0, 10))
            ),
			'decorators' => $this->dateDecorators,
        ));
		
		$this->addElement($this->_data);
		
		$this->addElement('button', 'calendar', array(
            'label'      => 'Scegli una data',
			'onClick' => 'makeCalendar(document.getElementById(\'data\'));',
			'decorators' => $this->buttonDateDecorators,

        ));
		
		
		
		$user = Zend_Auth::getInstance()->getIdentity();
		$table=new Model_Users();
		$rsArray = $table->getRolesByUser($user->id);
		$role=$table->getActiveRoles($rsArray); 
		
		$isAdm=($role['AMM']==1 || $role['AZI']==1);
		if(!$isAdm){
			$this->_progressivo->setAttrib('readonly',$isAdm);
			$this->_progressivo->setDecorators($this->proDecorators);
		}else{
			$this->_progressivo->setDecorators($this->textDecorators);
		}
		
		$this->_wasteSelect = new Zend_Form_Element_Select('id_rifiuto');
		$this->_wasteSelect->setLabel('Rifiuto:');
		$this->_wasteSelect->setAttrib('onChange','document.getElementById(\'quantita\').value=document.getElementById(\''.$user->id.'\'+this.value).value');
		
		$this->addElement($this->_wasteSelect);
		$this->_wasteSelect->setDecorators($this->textDecorators);
		
		$defaults=$table->getWasteByUser($user->id);
		
		
		if(!empty($defaults)){
			foreach($defaults as $waste){
			  $defaultUser = new Zend_Form_Element_Hidden($user->id.$waste['id']);
			  $defaultUser->setValue($waste['default']);
			  $defaultUser->setDecorators($this->buttonDateDecorators);
			  $this->addElement($defaultUser);
			}
		}
		
		$this->addElement('text', 'quantita', array(
            'label'      => 'Quantita\':',
            'required'   => true,
			'size'   => 5,
            'filters'    => array('StringTrim'),
            'validators' => array(
                 array('validator' => 'Float'),
				 array('validator' => 'StringLength', 'options' => array(0, 5))
            ),
			'onFocus' => 'document.getElementById(\'quantita\').value=document.getElementById(\''.$user->id.'\'+document.getElementById(\'id_rifiuto\').value).value',
			'decorators' => $this->textDecorators,
        ));
		
		$this->_udmSelect = new Zend_Form_Element_Select('id_unita_di_misura');
		$this->_udmSelect->setLabel('Unita\' di misura:');
		$this->_udmSelect->setDecorators($this->textDecorators);
		$table=new UdM();
		$rows=$table->fetchAll()->toArray();
		if(!empty($rows)){
			foreach($rows as $ruolo){
			  $this->_udmSelect->addMultiOption($ruolo['id'], $ruolo['unita_misura']);
			}
		}
		
		$this->addElement($this->_udmSelect);
		
		
		$this->addElement('textarea', 'note', array(
            'label'      => 'Note:',
            'filters'    => array('StringTrim'),
			'decorators' => $this->textDecorators,
        ));
		
		$this->addElement('hidden', 'print', array(
            'value'		=> '0'
        ));

        $this->addElement('submit', 'submit', array(
            'label'    => 'Conferma',
			'decorators' => $this->buttonDateDecorators,
        ));
		
		$this->addElement('submit', 'submitandbook', array(
            'label'    => 'Conferma e stampa',
			'onClick'  => 'document.getElementById(\'print\').value=1;',
			'decorators' => $this->buttonPrintDateDecorators,
        ));
    }
	
	public function setWasteSelect($userid)
	{
		$table=new Model_Users();
		$rows=$table->getWasteByUser($userid);
		
		
		if(!empty($rows)){
			foreach($rows as $waste){
			  $this->_wasteSelect->addMultiOption($waste['id'], $waste['cer']." - ".$waste['descrizione']);
			}
		}
	}
	
	public function setProgressivo($value)
	{
		$this->_progressivo->setValue($value);
	}
	
	
	public function getWaste()
	{
		return $this->_wasteSelect->getValue();
	} 
}
?>